"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QAudioSource(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qaudiosource.html

    **Detailed Description**

    You can construct an audio input with the system's default audio input
    device. It is also possible to create QAudioSource with a specific
    **QAudioDevice** . When you create the audio input, you should also send in
    the **QAudioFormat**  to be used for the recording (see the **QAudioFormat**
    class description for details).

    To record to a file:

    QAudioSource lets you record audio with an audio input device. The default
    constructor of this class will use the systems default audio device, but you
    can also specify a **QAudioDevice**  for a specific device. You also need to
    pass in the **QAudioFormat**  in which you wish to record.

    Starting up the QAudioSource is simply a matter of calling **start** () with
    a **QIODevice**  opened for writing. For instance, to record to a file, you
    can:

    **QFile**  destinationFile;   // Class member
        **QAudioSource** * audio;
    // Class member
        {
            destinationFile.setFileName("/tmp/test.raw");
    destinationFile.open( **QIODevice** ::WriteOnly | **QIODevice** ::Truncate
    );

            **QAudioFormat**  format;
            // Set up the desired
    format, for example:
            format.setSampleRate(8000);
    format.setChannelCount(1);
            format.setSampleFormat(**QAudioFormat**
    ::UInt8);

            **QAudioDevice**  info = **QMediaDevices**
    ::defaultAudioInput();
            if (!info.isFormatSupported(format)) {
    **qWarning** () << "Default format not supported, trying to use the
    nearest.";
            }

            audio = new **QAudioSource** (format,
    this);
            connect(audio, SIGNAL(stateChanged(QAudio::State)), this,
    SLOT(handleStateChanged(QAudio::State)));

            **QTimer**
    ::singleShot(3000, this, SLOT(stopRecording()));
    audio->start(&destinationFile);
            // Records audio for 3000ms
        }

    This will start recording if the format specified is supported by the input
    device (you can check this with **QAudioDevice::isFormatSupported** (). In
    case there are any snags, use the **error** () function to check what went
    wrong. We stop recording in the `stopRecording()` slot.

    void AudioInputExample::stopRecording()
        {
            audio->stop();
    destinationFile.close();
            delete audio;
        }

    At any point in time, QAudioSource will be in one of four states: active,
    suspended, stopped, or idle. These states are specified by the
    **QAudio::State**  enum. You can request a state change directly through
    **suspend** (), **resume** (), **stop** (), **reset** (), and **start** ().
    The current state is reported by **state** (). **QAudioSink**  will also
    signal you when the state changes (**stateChanged** ()).

    QAudioSource provides several ways of measuring the time that has passed
    since the **start** () of the recording. The `processedUSecs()` function
    returns the length of the stream in microseconds written, i.e., it leaves
    out the times the audio input was suspended or idle. The **elapsedUSecs** ()
    function returns the time elapsed since **start** () was called regardless
    of which states the QAudioSource has been in.

    If an error should occur, you can fetch its reason with **error** (). The
    possible error reasons are described by the **QAudio::Error**  enum. The
    QAudioSource will enter the **StoppedState**  when an error is encountered.
    Connect to the **stateChanged** () signal to handle the error:

    void AudioInputExample::handleStateChanged(QAudio::State newState)
        {
    switch (newState) {
                case QAudio::StoppedState:
    if (audio->error() != QAudio::NoError) {
                        // Error
    handling
                    } else {
                        // Finished recording
    }
                    break;

                case QAudio::ActiveState:
    // Started recording - read from IO device
                    break;
    default:
                    // ... other cases as appropriate
    break;
            }
        }

    **See also** **QAudioSink**  and **QAudioDevice** .
    """

    @typing.overload
    def __init__(
        self,
        audioDeviceInfo: QAudioDevice,
        format: QAudioFormat = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#QAudioSource

        **QAudioSource::QAudioSource(const QAudioFormat & format =
        QAudioFormat(), QObject * parent = nullptr)**

        Construct a new audio input and attach it to **parent**. The default
        audio input device is used with the output **format** parameters.
        """
        ...

    @typing.overload
    def __init__(
        self, format: QAudioFormat = ..., parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#QAudioSource-1

        **QAudioSource::QAudioSource(const QAudioDevice & audioDevice , const
        QAudioFormat & format = QAudioFormat(), QObject * parent = nullptr)**

        Construct a new audio input and attach it to **parent**. The device
        referenced by **audioDevice** is used with the input **format**
        parameters.
        """
        ...

    def state(self) -> QAudio.State:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#state

        **QAudio::State QAudioSource::state() const**

        Returns the state of audio processing.
        """
        ...

    def error(self) -> QAudio.Error:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#error

        **QAudio::Error QAudioSource::error() const**

        Returns the error state.
        """
        ...

    def elapsedUSecs(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#elapsedUSecs

        **qint64 QAudioSource::elapsedUSecs() const**

        Returns the microseconds since **start** () was called, including time
        in Idle and Suspend states.
        """
        ...

    def processedUSecs(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#processedUSecs

        **qint64 QAudioSource::processedUSecs() const**

        Returns the amount of audio data processed since **start** () was called
        in microseconds.
        """
        ...

    def volume(self) -> float:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#volume

        **qreal QAudioSource::volume() const**

        Returns the input volume.

        If the device does not support adjusting the input volume the returned
        value will be 1.0.

        **See also** **setVolume** ().
        """
        ...

    def setVolume(self, volume: float) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#setVolume

        **void QAudioSource::setVolume(qreal volume )**

        Sets the input volume to **volume**.

        The volume is scaled linearly from `0.0` (silence) to `1.0` (full
        volume). Values outside this range will be clamped.

        If the device does not support adjusting the input volume then
        **volume** will be ignored and the input volume will remain at 1.0.

        The default volume is `1.0`.

        Note: Adjustments to the volume will change the volume of this audio
        stream, not the global volume.

        **See also** **volume** ().
        """
        ...

    def bytesAvailable(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#bytesAvailable

        **qsizetype QAudioSource::bytesAvailable() const**

        Returns the amount of audio data available to read in bytes.

        Note: returned value is only valid while in **QAudio::ActiveState**  or
        **QAudio::IdleState**  state, otherwise returns zero.
        """
        ...

    def bufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#bufferSize

        **qsizetype QAudioSource::bufferSize() const**

        Returns the audio buffer size in bytes.

        If called before **start** (), returns platform default value. If called
        before **start** () but **setBufferSize** () was called prior, returns
        value set by **setBufferSize** (). If called after **start** (), returns
        the actual buffer size being used. This may not be what was set
        previously by **setBufferSize** ().

        **See also** **setBufferSize** ().
        """
        ...

    def setBufferSize(self, bytes: int) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#setBufferSize

        **void QAudioSource::setBufferSize(qsizetype value )**

        Sets the audio buffer size to **value** bytes.

        Note: This function can be called anytime before **start** (), calls to
        this are ignored after **start** (). It should not be assumed that the
        buffer size set is the actual buffer size used, calling **bufferSize**
        () anytime after **start** () will return the actual buffer size being
        used.

        **See also** **bufferSize** ().
        """
        ...

    def resume(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#resume

        **void QAudioSource::resume()**

        Resumes processing audio data after a **suspend** ().

        Sets **error** () to **QAudio::NoError** . Sets **state** () to
        **QAudio::ActiveState**  if you previously called start(**QIODevice**
        *). Sets **state** () to **QAudio::IdleState**  if you previously called
        **start** (). emits **stateChanged** () signal.
        """
        ...

    def suspend(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#suspend

        **void QAudioSource::suspend()**

        Stops processing audio data, preserving buffered audio data.

        Sets **error** () to **QAudio::NoError** , **state** () to
        **QAudio::SuspendedState**  and emit **stateChanged** () signal.
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#reset

        **void QAudioSource::reset()**

        Drops all audio data in the buffers, resets buffers to zero.
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#stop

        **void QAudioSource::stop()**

        Stops the audio input, detaching from the system resource.

        Sets **error** () to **QAudio::NoError** , **state** () to
        **QAudio::StoppedState**  and emit **stateChanged** () signal.
        """
        ...

    @typing.overload
    def start(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#start

        **void QAudioSource::start(QIODevice * device )**

        Starts transferring audio data from the system's audio input to the
        **device**. The **device** must have been opened in the **WriteOnly** ,
        **Append**  or **ReadWrite**  modes.

        If the **QAudioSource**  is able to successfully get audio data,
        **state** () returns either **QAudio::ActiveState**  or
        **QAudio::IdleState** , **error** () returns **QAudio::NoError**  and
        the **stateChanged** () signal is emitted.

        If a problem occurs during this process, **error** () returns
        **QAudio::OpenError** , **state** () returns **QAudio::StoppedState**
        and the **stateChanged** () signal is emitted.

        **See also** **QIODevice** .
        """
        ...

    @typing.overload
    def start(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#start-1

        **QIODevice *QAudioSource::start()**

        Returns a pointer to the internal **QIODevice**  being used to transfer
        data from the system's audio input. The device will already be open and
        **read** () can read data directly from it.

        **Note:** The pointer will become invalid after the stream is stopped or
        if you start another stream.

        If the **QAudioSource**  is able to access the system's audio device,
        **state** () returns **QAudio::IdleState** , **error** () returns
        **QAudio::NoError**  and the **stateChanged** () signal is emitted.

        If a problem occurs during this process, **error** () returns
        **QAudio::OpenError** , **state** () returns **QAudio::StoppedState**
        and the **stateChanged** () signal is emitted.

        **See also** **QIODevice** .
        """
        ...

    def format(self) -> QAudioFormat:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#format

        **QAudioFormat QAudioSource::format() const**

        Returns the **QAudioFormat**  being used.
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiosource.html#stateChanged

        **[signal] void QAudioSource::stateChanged(QAudio::State state )**

        This signal is emitted when the device **state** has changed.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QAxContainer import *


class QAxBase(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qaxbase.html

    **Detailed Description**

    QAxBase is an abstract class that cannot be used directly, and is
    instantiated through the subclasses **QAxObject**  and **QAxWidget** . This
    class provides the API to access the COM object directly through its
    IUnknown implementation. If the COM object implements the IDispatch
    interface, the properties and methods of that object become available as Qt
    properties and slots.

    connect(buttonBack, SIGNAL(clicked()), webBrowser, SLOT(GoBack()));

    Properties exposed by the object's IDispatch implementation can be read and
    written through the property system provided by the Qt Object Model (both
    subclasses are **QObject** s, so you can use **QObject::setProperty** () and
    **QObject::property** ()). Properties with multiple parameters are not
    supported.

    activeX->setProperty("text", "some text");
        int value =
    activeX->property("value");

    Write-functions for properties and other methods exposed by the object's
    IDispatch implementation can be called directly using **dynamicCall** (), or
    indirectly as slots connected to a signal.

    webBrowser->dynamicCall("GoHome()");

    Outgoing events supported by the COM object are emitted as standard Qt
    signals.

    connect(webBrowser, SIGNAL(TitleChanged(**QString** )),
                this,
    SLOT(setCaption(**QString** )));

    QAxBase transparently converts between COM data types and the equivalent Qt
    data types. Some COM types have no equivalent Qt data structure.

    Supported COM datatypes are listed in the first column of following table.
    The second column is the Qt type that can be used with the **QObject**
    property functions. The third column is the Qt type that is used in the
    prototype of generated signals and slots for in-parameters, and the last
    column is the Qt type that is used in the prototype of signals and slots for
    out-parameters.

    COM typeQt propertyin-parameterout-parameter
    VARIANT_BOOLboolboolbool&
    BSTR**QString** const **QString** &**QString** &
    char, short, int,
    longintintint&
    uchar, ushort, uint, ulonguintuintuint&
    float,
    doubledoubledoubledouble&
    DATE**QDateTime** const **QDateTime**
    &**QDateTime** &
    CYqlonglongqlonglongqlonglong&
    OLE_COLOR**QColor**
    const **QColor** &**QColor** &
    SAFEARRAY(VARIANT)**QList** <**QVariant**
    >const **QList** <**QVariant** >&**QList** <**QVariant** >&
    SAFEARRAY(int), SAFEARRAY(double), SAFEARRAY(Date)**QList** <**QVariant**
    >const **QList** <**QVariant** >&**QList** <**QVariant** >&
    SAFEARRAY(BYTE)**QByteArray** const **QByteArray** &**QByteArray** &
    SAFEARRAY(BSTR)**QStringList** const **QStringList** &**QStringList** &
    VARIANTtype-dependentconst **QVariant** &**QVariant** &
    IFontDisp***QFont** const **QFont** &**QFont** &
    IPictureDisp***QPixmap**
    const **QPixmap** &**QPixmap** &
    IDispatch***QAxObject**
    *`QAxBase::asVariant()`**QAxObject** * (return value)
    IUnknown***QAxObject** *`QAxBase::asVariant()`**QAxObject** * (return value)
    SCODE, DECIMAL **unsupported** **unsupported** **unsupported**
    VARIANT*
    (Since Qt 4.5) **unsupported** **QVariant &** **QVariant &**

    Supported are also enumerations, and typedefs to supported types.

    To call the methods of a COM interface described by the following IDL

    dispinterface IControl
        {
        properties:
            [id(1)] BSTR text;
    [id(2)] IFontDisp *font;

        methods:
            [id(6)] void
    showColumn([in] int i);
            [id(3)] bool addColumn([in] BSTR t);
    [id(4)] int fillList([in, out] SAFEARRAY(VARIANT) *list);
            [id(5)]
    IDispatch *item([in] int i);
        };

    use the QAxBase API like this:

    **QAxObject**  object("<CLSID>");

        **QString**  text =
    object.property("text").toString();
        object.setProperty("font", **QFont**
    ("Times New Roman", 12));

        connect(this, SIGNAL(clicked(int)),
    &object, SLOT(showColumn(int)));
        bool ok =
    object.dynamicCall("addColumn(const QString&)", "Column 1").toBool();
    **QList** <**QVariant** > varlist;
        **QList** <**QVariant** > parameters;
    parameters << **QVariant** (varlist);
        int n =
    object.dynamicCall("fillList(QList<QVariant>&)", parameters).toInt();
    **QAxObject**  *item = object.querySubItem("item(int)", 5);

    Note that the **QList**  the object should fill has to be provided as an
    element in the parameter list of **QVariant** s.

    If you need to access properties or pass parameters of unsupported datatypes
    you must access the COM object directly through its `IDispatch`
    implementation or other interfaces. Those interfaces can be retrieved
    through **queryInterface** ().

    IUnknown *iface = 0;
        activeX->queryInterface(IID_IUnknown,
    (void**)&iface);
        if (iface) {
            // use the interface
    iface->Release();
        }

    To get the definition of the COM interfaces you will have to use the header
    files provided with the component you want to use. Some compilers can also
    import type libraries using the #import compiler directive. See the
    component documentation to find out which type libraries you have to import,
    and how to use them.

    If you need to react to events that pass parameters of unsupported datatypes
    you can use the generic signal that delivers the event data as provided by
    the COM event.

    **See also** **QAxObject** , **QAxWidget** , **QAxScript** , and **ActiveQt
    Framework** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#QAxBase

        **[protected] QAxBase::QAxBase()**

        Creates a QAxBase object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QAxBase") -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#QAxBase

        **[protected] QAxBase::QAxBase()**

        Creates a QAxBase object.
        """
        ...

    def setClassContext(self, classContext: int) -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#setClassContext

        **[since 5.13] void QAxBase::setClassContext(ulong classContext )**

        Sets the context the ActiveX control will run in to **classContext**

        Affects the "dwClsContext" argument when calling CoCreateInstance. This
        can be used to control in-proc vs. out-of-proc startup for controls
        supporting both alternatives. Also, it can be used to modify/reduce
        control permissions when used with CLSCTX_ENABLE_CLOAKING and an
        impersonation token.

        Note that this function must be called before setControl() to have any
        effect.

        This function was introduced in Qt 5.13.

        **See also** **classContext** ().
        """
        ...

    def classContext(self) -> int:
        """
        https://doc.qt.io/qt-6/qaxbase.html#classContext

        **[since 5.13] ulong QAxBase::classContext() const**

        Returns the context the ActiveX control will run in (default
        CLSCTX_SERVER).

        This function was introduced in Qt 5.13.

        **See also** **setClassContext** ().
        """
        ...

    def disableEventSink(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#disableEventSink

        **void QAxBase::disableEventSink()**

        Disables the event sink implementation for this ActiveX container. If
        you don't intend to listen to the ActiveX control's events use this
        function to speed up the meta object generation.

        Some ActiveX controls might be unstable when connected to an event sink.
        To get OLE events you must use standard COM methods to register your own
        event sink. Use **queryInterface** () to get access to the raw COM
        object.

        Note that this function should be called immediately after construction
        of the object.
        """
        ...

    def disableClassInfo(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#disableClassInfo

        **void QAxBase::disableClassInfo()**

        Disables the class info generation for this ActiveX container. If you
        don't require any class information about the ActiveX control use this
        function to speed up the meta object generation.

        Note that this function must be called immediately after construction of
        the object
        """
        ...

    def disableMetaObject(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#disableMetaObject

        **void QAxBase::disableMetaObject()**

        Disables the meta object generation for this ActiveX container. This
        also disables the event sink and class info generation. If you don't
        intend to use the Qt meta object implementation call this function to
        speed up instantiation of the control. You will still be able to call
        the object through **dynamicCall** (), but signals, slots and properties
        will not be available with **QObject**  APIs.

        Some ActiveX controls might be unstable when used with OLE automation.
        Use standard COM methods to use those controls through the COM
        interfaces provided by **queryInterface** ().

        Note that this function must be called immediately after construction of
        the object.
        """
        ...

    def setControl(self, a0: str) -> bool:
        """
        https://doc.qt.io/qt-6/qaxbase.html#control

        **QString QAxBase::control() const**

        Returns the ActiveX control.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#clear

        **void QAxBase::clear()**

        Disconnects and destroys the COM object.

        If you reimplement this function you must also reimplement the
        destructor to call clear(), and call this implementation at the end of
        your clear() function.
        """
        ...

    def asVariant(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qaxbase.html#asVariant

        **QVariant QAxBase::asVariant() const**

        Returns a **QVariant**  that wraps the COM object. The variant can then
        be used as a parameter in e.g. **dynamicCall** ().
        """
        ...

    def verbs(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qaxbase.html#verbs

        **QStringList QAxBase::verbs() const**

        Returns the list of verbs that the COM object can execute. If the object
        does not implement IOleObject, or does not support any verbs, then this
        function returns an empty stringlist.

        Note that the OLE default verbs (OLEIVERB_SHOW etc) are not included in
        the list.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaxbase.html#isNull

        **bool QAxBase::isNull() const**

        Returns true if there is no COM object loaded by this wrapper; otherwise
        return false.

        **See also** **control** ().
        """
        ...

    def setPropertyWritable(self, a0: str, a1: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#setPropertyWritable

        **[virtual] void QAxBase::setPropertyWritable(const char * prop , bool
        ok )**

        Sets the property **prop** to writable if **ok** is true, otherwise sets
        **prop** to be read-only. By default, all properties are writable.

        **Warning:** Depending on the control implementation this setting might
        be ignored for some properties.

        **See also** **propertyWritable** (), **QAxBaseWidget::propertyChanged**
        (), and **QAxBaseObject::propertyChanged** ().
        """
        ...

    def propertyWritable(self, a0: str) -> bool:
        """
        https://doc.qt.io/qt-6/qaxbase.html#propertyWritable

        **[virtual] bool QAxBase::propertyWritable(const char * prop ) const**

        Returns true if the property **prop** is writable; otherwise returns
        false. By default, all properties are writable.

        **Warning:** Depending on the control implementation this setting might
        be ignored for some properties.

        **See also** **setPropertyWritable** (),
        **QAxBaseWidget::propertyChanged** (), and
        **QAxBaseObject::propertyChanged** ().
        """
        ...

    def generateDocumentation(self) -> str:
        """
        https://doc.qt.io/qt-6/qaxbase.html#generateDocumentation

        **QString QAxBase::generateDocumentation()**

        Returns a rich text string with documentation for the wrapped COM
        object. Dump the string to an HTML-file, or use it in e.g. a
        **QTextBrowser**  widget.
        """
        ...

    def setPropertyBag(self, a0: typing.Dict[str, typing.Any]) -> None:
        """
        https://doc.qt.io/qt-6/qaxbase.html#setPropertyBag

        **void QAxBase::setPropertyBag(const QAxBase::PropertyBag & bag )**

        Sets the properties of the COM object to the corresponding values in
        **bag**.

        **Warning:** You should only set property bags that have been returned
        by the **propertyBag**  function, as it cannot be guaranteed that the
        property bag implementation of the COM object supports the same
        properties that are available through the IDispatch interface.

        **See also** **propertyBag** ().
        """
        ...

    def propertyBag(self) -> typing.Dict[str, typing.Any]:
        """
        https://doc.qt.io/qt-6/qaxbase.html#propertyBag

        **QAxBase::PropertyBag QAxBase::propertyBag() const**

        Returns a name:value map of all the properties exposed by the COM
        object.

        This is more efficient than getting multiple properties individually if
        the COM object supports property bags.

        **Warning:** It is not guaranteed that the property bag implementation
        of the COM object returns all properties, or that the properties
        returned are the same as those available through the IDispatch
        interface.

        **See also** **setPropertyBag** ().
        """
        ...

    @typing.overload
    def querySubObject(self, a0: str, a1: typing.Iterable[typing.Any]) -> "QAxObject":
        """
        https://doc.qt.io/qt-6/qaxbase.html#querySubObject

        **QAxObject *QAxBase::querySubObject(const char * name , const QVariant
        & var1 = QVariant(), const QVariant & var2 = QVariant(), const QVariant
        & var3 = QVariant(), const QVariant & var4 = QVariant(), const QVariant
        & var5 = QVariant(), const QVariant & var6 = QVariant(), const QVariant
        & var7 = QVariant(), const QVariant & var8 = QVariant())**

        Returns a pointer to a **QAxObject**  wrapping the COM object provided
        by the method or property **name** , passing passing the parameters
        **var1** , **var1** , **var2** , **var3** , **var4** , **var5** ,
        **var6** , **var7** and **var8**.

        If **name** is provided by a method the string must include the full
        function prototype.

        If **name** is a property the string must be the name of the property,
        and **var1** , ... **var8** are ignored.

        The returned **QAxObject**  is a child of this object (which is either
        of type **QAxObject**  or **QAxWidget** ), and is deleted when this
        object is deleted. It is however safe to delete the returned object
        yourself, and you should do so when you iterate over lists of
        subobjects.

        COM enabled applications usually have an object model publishing certain
        elements of the application as dispatch interfaces. Use this method to
        navigate the hierarchy of the object model, e.g.

        **QAxWidget**  outlook("Outlook.Application");
            **QAxObject**
        *session = outlook.querySubObject("Session");
            if (session) {
        **QAxObject**  *defFolder = session->querySubObject(
        "GetDefaultFolder(OlDefaultFolders)",
        "olFolderContacts");
                //...
            }
        """
        ...

    @typing.overload
    def querySubObject(
        self,
        a0: str,
        value1: typing.Any = ...,
        value2: typing.Any = ...,
        value3: typing.Any = ...,
        value4: typing.Any = ...,
        value5: typing.Any = ...,
        value6: typing.Any = ...,
        value7: typing.Any = ...,
        value8: typing.Any = ...,
    ) -> "QAxObject":
        """
        https://doc.qt.io/qt-6/qaxbase.html#querySubObject-1

        **QAxObject *QAxBase::querySubObject(const char * name , QList<QVariant>
        & vars )**

        This is an overloaded function.

        The **QVariant**  objects in **vars** are updated when the method has
        out-parameters.
        """
        ...

    @typing.overload
    def dynamicCall(self, a0: str, a1: typing.Iterable[typing.Any]) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qaxbase.html#dynamicCall

        **QVariant QAxBase::dynamicCall(const char * function , const QVariant &
        var1 = QVariant(), const QVariant & var2 = QVariant(), const QVariant &
        var3 = QVariant(), const QVariant & var4 = QVariant(), const QVariant &
        var5 = QVariant(), const QVariant & var6 = QVariant(), const QVariant &
        var7 = QVariant(), const QVariant & var8 = QVariant())**

        Calls the COM object's method **function** , passing the parameters
        **var1** , **var1** , **var2** , **var3** , **var4** , **var5** ,
        **var6** , **var7** and **var8** , and returns the value returned by the
        method, or an invalid **QVariant**  if the method does not return a
        value or when the function call failed.

        If **function** is a method of the object the string must be provided as
        the full prototype, for example as it would be written in a
        **QObject::connect** () call.

        activeX->dynamicCall("Navigate(const QString&)", "www.qt-project.org");

        Alternatively a function can be called passing the parameters embedded
        in the string, e.g. above function can also be invoked using

        activeX->dynamicCall("Navigate(\\"www.qt-project.org\\")");

        All parameters are passed as strings; it depends on the control whether
        they are interpreted correctly, and is slower than using the prototype
        with correctly typed parameters.

        If **function** is a property the string has to be the name of the
        property. The property setter is called when **var1** is a valid
        **QVariant** , otherwise the getter is called.

        activeX->dynamicCall("Value", 5);
            **QString**  text =
        activeX->dynamicCall("Text").toString();

        Note that it is faster to get and set properties using
        **QObject::property** () and **QObject::setProperty** ().

        dynamicCall() can also be used to call objects with a **disabled
        metaobject**  wrapper, which can improve performance significantely,
        esp. when calling many different objects of different types during an
        automation process. ActiveQt will then however not validate parameters.

        It is only possible to call functions through dynamicCall() that have
        parameters or return values of datatypes supported by **QVariant** . See
        the **QAxBase**  class documentation for a list of supported and
        unsupported datatypes. If you want to call functions that have
        unsupported datatypes in the parameter list, use **queryInterface** ()
        to retrieve the appropriate COM interface, and use the function
        directly.

        IWebBrowser2 *webBrowser = 0;
        activeX->queryInterface(IID_IWebBrowser2, (void **)&webBrowser);
            if
        (webBrowser) {
                webBrowser->Navigate2(pvarURL);
        webBrowser->Release();
            }

        This is also more efficient.
        """
        ...

    @typing.overload
    def dynamicCall(
        self,
        a0: str,
        value1: typing.Any = ...,
        value2: typing.Any = ...,
        value3: typing.Any = ...,
        value4: typing.Any = ...,
        value5: typing.Any = ...,
        value6: typing.Any = ...,
        value7: typing.Any = ...,
        value8: typing.Any = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qaxbase.html#dynamicCall-1

        **QVariant QAxBase::dynamicCall(const char * function , QList<QVariant>
        & vars )**

        This is an overloaded function.

        Calls the COM object's method **function** , passing the parameters in
        **vars** , and returns the value returned by the method. If the method
        does not return a value or when the function call failed this function
        returns an invalid **QVariant**  object.

        The **QVariant**  objects in **vars** are updated when the method has
        out-parameters.
        """
        ...

    def control(self) -> str:
        """
        https://doc.qt.io/qt-6/qaxbase.html#control

        **QString QAxBase::control() const**

        Returns the ActiveX control.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui


class QQuick3D(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qquick3d.html

    **Detailed Description**

    When using Qt Quick 3D with OpenGL it is necessary to take extra steps to
    define what kind of **surface format**  is used when initializing Qt Quick.
    This is because by the time Qt Quick is aware that 3D content is being used,
    the OpenGL context and window surface has already been initialized. So this
    helper class is provided to request the ideal surface format from Qt Quick
    3D so that it can be set as the default surface for Qt Quick before
    initialization.

    If this helper is run when using any other rendering backends than OpenGL
    then it just returns a copy of the current default **QSurfaceFormat**  with
    the requested samples.

    If this helper is run when using the OpenGL rendering backend, then it will
    test for sufficiently modern versions of OpenGL and support for
    multisampling if requested. Normally Qt Quick will request an OpenGL 2.0 or
    OpenGL ES 2.0 context, which would limit the features available when using
    Qt Quick 3D, so an extra step is needed to request a more capable context.

    The correct usage pattern is to call **QSurfaceFormat::setDefaultFormat**
    to set the **QSurfaceFormat**  returned by **QQuick3D::idealSurfaceFormat**
    . It is important that this method is called after **QGuiApplication**  is
    constructed, but before the Qt Quick application content is loaded. This
    code snippet shows the correct usage pattern:

    #include <QGuiApplication>
        #include <QQmlApplicationEngine>
    #include <QtGui>
        #include <QtQuick3D/qquick3d.h>

        int main(int
    argc, char *argv[])
        {
            **QGuiApplication**  app(argc, argv);
    **QSurfaceFormat** ::setDefaultFormat(QQuick3D::idealSurfaceFormat(4));
    **QQmlApplicationEngine**  engine;
            engine.load(**QUrl**
    (**QStringLiteral** ("qrc:/main.qml")));
            if
    (engine.rootObjects().isEmpty())
                return -1;

            return
    app.exec();
        }
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QQuick3D") -> None:
        ...

    @staticmethod
    def idealSurfaceFormat(samples: int = ...) -> QtGui.QSurfaceFormat:
        """
        https://doc.qt.io/qt-6/qquick3d.html#idealSurfaceFormat

        **[static] QSurfaceFormat QQuick3D::idealSurfaceFormat(int samples =
        -1)**

        Returns an ideal surface format for the platform. Optionally,
        **samples** can be specified to select the number of multisamples for
        antialiasing.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTextObjectInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextobjectinterface.html

    **Detailed Description**

    A text object describes the structure of one or more elements in a text
    document; for instance, images imported from HTML are implemented using text
    objects. A text object knows how to lay out and draw its elements when a
    document is being rendered.

    Qt allows custom text objects to be inserted into a document by registering
    a custom **object type**  with **QTextCharFormat** . A QTextObjectInterface
    must also be implemented for this type and be **registered**  with the
    **QAbstractTextDocumentLayout**  of the document. When the object type is
    encountered while rendering a **QTextDocument** , the **intrinsicSize** ()
    and **drawObject** () functions of the interface are called.

    The following list explains the required steps of inserting a custom text
    object into a document:

    * Choose an **objectType**. The **objectType** is an integer with a value
    greater or equal to **QTextFormat::UserObject** .
      * Create a
    **QTextCharFormat**  object and set the object type to the chosen type using
    the setObjectType() function.
      * Implement the QTextObjectInterface class.
    * Call **QAbstractTextDocumentLayout::registerHandler** () with an instance
    of your QTextObjectInterface subclass to register your object type.
      *
    Insert **QChar::ObjectReplacementCharacter**  with the aforementioned
    **QTextCharFormat**  of the chosen object type into the document. As
    mentioned, the functions of QTextObjectInterface **intrinsicSize** () and
    **drawObject** () will then be called with the **QTextFormat**  as parameter
    whenever the replacement character is encountered.

    A class implementing a text object needs to inherit both **QObject**  and
    QTextObjectInterface. **QObject**  must be the first class inherited. For
    instance:

    class SvgTextObject : public **QObject** , public **QTextObjectInterface**
    {
            Q_OBJECT
            Q_INTERFACES(**QTextObjectInterface** )

    The data of a text object is usually stored in the **QTextCharFormat**
    using **QTextCharFormat::setProperty** (), and then retrieved with
    **QTextCharFormat::property** ().

    **Warning:** Copy and Paste operations ignore custom text objects.

    **See also** **Text Object Example** , **QTextCharFormat** , and
    **QTextLayout** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QTextObjectInterface") -> None:
        ...

    def drawObject(
        self,
        painter: "QPainter",
        rect: QtCore.QRectF,
        doc: "QTextDocument",
        posInDocument: int,
        format: "QTextFormat",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextobjectinterface.html#drawObject

        **[pure virtual] void QTextObjectInterface::drawObject(QPainter *
        painter , const QRectF & rect , QTextDocument * doc , int posInDocument
        , const QTextFormat & format )**

        Draws this text object using the specified **painter**.

        The size of the rectangle, **rect** , to draw in is the size previously
        calculated by **intrinsicSize** (). The rectangles position is relative
        to the **painter**.

        You also get the document ( **doc** ) and the position (
        **posInDocument** ) of the **format** in that document.

        **See also** **intrinsicSize** ().
        """
        ...

    def intrinsicSize(
        self, doc: "QTextDocument", posInDocument: int, format: "QTextFormat"
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qtextobjectinterface.html#intrinsicSize

        **[pure virtual] QSizeF
        QTextObjectInterface::intrinsicSize(QTextDocument * doc , int
        posInDocument , const QTextFormat & format )**

        The intrinsicSize() function returns the size of the text object
        represented by **format** in the given document ( **doc** ) at the given
        position ( **posInDocument** ).

        The size calculated will be used for subsequent calls to **drawObject**
        () for this **format**.

        **See also** **drawObject** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtNetwork
from PyQt6 import QtCore
from PyQt6.QtQml import *


class QQmlEngine(QJSEngine):
    """
    https://doc.qt.io/qt-6/qqmlengine.html

    **Detailed Description**

    Each QML component is instantiated in a **QQmlContext** . **QQmlContext** 's
    are essential for passing data to QML components. In QML, contexts are
    arranged hierarchically and this hierarchy is managed by the QQmlEngine.

    Prior to creating any QML components, an application must have created a
    QQmlEngine to gain access to a QML context. The following example shows how
    to create a simple Text item.

    **QQmlEngine**  engine;
        **QQmlComponent**  component(&engine);
    component.setData("import QtQuick 2.0\\nText { text: \\"Hello world!\\" }",
    **QUrl** ());
        **QQuickItem**  *item = qobject_cast<**QQuickItem**
    *>(component.create());

        //add item to view, etc
        ...

    In this case, the Text item will be created in the engine's **root context**
    .

    **See also** **QQmlComponent** , **QQmlContext** , and **QML Global Object**
    .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#QQmlEngine

        **QQmlEngine::QQmlEngine(QObject * parent = nullptr)**

        Create a new QQmlEngine with the given **parent**.
        """
        ...

    def urlInterceptors(self) -> typing.List[QQmlAbstractUrlInterceptor]:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#urlInterceptors

        **QList<QQmlAbstractUrlInterceptor *> QQmlEngine::urlInterceptors()
        const**

        Returns the list of currently active URL interceptors.
        """
        ...

    def interceptUrl(
        self, url: QtCore.QUrl, type: QQmlAbstractUrlInterceptor.DataType
    ) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#interceptUrl

        **QUrl QQmlEngine::interceptUrl(const QUrl & url ,
        QQmlAbstractUrlInterceptor::DataType type ) const**

        Run the current URL interceptors on the given **url** of the given
        **type** and return the result.
        """
        ...

    def removeUrlInterceptor(self, urlInterceptor: QQmlAbstractUrlInterceptor) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#removeUrlInterceptor

        **void QQmlEngine::removeUrlInterceptor(QQmlAbstractUrlInterceptor *
        urlInterceptor )**

        Remove a **urlInterceptor** that was previously added using
        **addUrlInterceptor** . The URL interceptors should not be modifed while
        the engine is loading files, or URL selection may be inconsistent.

        This does not delete the interceptor, but merely removes it from the
        engine. You can re-use it on the same or a different engine afterwards.
        """
        ...

    def addUrlInterceptor(self, urlInterceptor: QQmlAbstractUrlInterceptor) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#addUrlInterceptor

        **void QQmlEngine::addUrlInterceptor(QQmlAbstractUrlInterceptor *
        urlInterceptor )**

        Adds a **urlInterceptor** to be used when resolving URLs in QML. This
        also applies to URLs used for loading script files and QML types. The
        URL interceptors should not be modifed while the engine is loading
        files, or URL selection may be inconsistent. Multiple URL interceptors,
        when given, will be called in the order they were added for each URL.

        **QQmlEngine**  does not take ownership of the interceptor and won't
        delete it.
        """
        ...

    def singletonInstance(self, qmlTypeId: int) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#singletonInstance

        **[since 5.12] template <typename T> T QQmlEngine::singletonInstance(int
        qmlTypeId )**

        Returns the instance of a singleton type that was registered under
        **qmlTypeId**.

        The template argument **T** may be either **QJSValue**  or a pointer to
        a **QObject** -derived type and depends on how the singleton was
        registered. If no instance of **T** has been created yet, it is created
        now. If **qmlTypeId** does not represent a valid singleton type, either
        a default constructed **QJSValue**  or a `nullptr` is returned.

        **QObject** * example:

        class MySingleton : public **QObject**  {
                Q_OBJECT
        // Register as default constructed singleton.
                QML_ELEMENT
        QML_SINGLETON

                static int typeId;
                // ...
            };
        MySingleton::typeId = qmlTypeId(...);

                // Retrieve as
        QObject*
                **QQmlEngine**  engine;
                MySingleton* instance =
        engine.singletonInstance<MySingleton\\*>(MySingleton::typeId);

        **QJSValue**  example:

        // Register with QJSValue callback
                int typeId =
        qmlRegisterSingletonType(...);

                // Retrieve as QJSValue
        **QQmlEngine**  engine;
                **QJSValue**  instance =
        engine.singletonInstance<**QJSValue** >(typeId);

        It is recommended to store the QML type id, e.g. as a static member in
        the singleton class. The lookup via **qmlTypeId** () is costly.

        This function was introduced in Qt 5.12.

        **See also** **QML_SINGLETON** , **qmlRegisterSingletonType** (), and
        **qmlTypeId** ().
        """
        ...

    def offlineStorageDatabaseFilePath(self, databaseName: str) -> str:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#offlineStorageDatabaseFilePath

        **[since 5.9] QString QQmlEngine::offlineStorageDatabaseFilePath(const
        QString & databaseName ) const**

        Returns the file path where a **Local Storage**  database with the
        identifier **databaseName** is (or would be) located.

        This function was introduced in Qt 5.9.

        **See also** **LocalStorage.openDatabaseSync()** .
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#event

        **[override virtual protected] bool QQmlEngine::event(QEvent * e )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def retranslate(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#retranslate

        **[slot, since 5.10] void QQmlEngine::retranslate()**

        Refreshes all binding expressions that use strings marked for
        translation.

        Call this function after you have installed a new translator with
        **QCoreApplication::installTranslator** , to ensure that your user-
        interface shows up-to-date translations.

        This function was introduced in Qt 5.10.
        """
        ...

    @staticmethod
    def setContextForObject(a0: QtCore.QObject, a1: "QQmlContext") -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#setContextForObject

        **[static] void QQmlEngine::setContextForObject(QObject * object ,
        QQmlContext * context )**

        Sets the **QQmlContext**  for the **object** to **context**. If the
        **object** already has a context, a warning is output, but the context
        is not changed.

        When the **QQmlEngine**  instantiates a **QObject** , the context is set
        automatically.

        **See also** **contextForObject** ().
        """
        ...

    @staticmethod
    def contextForObject(a0: QtCore.QObject) -> "QQmlContext":
        """
        https://doc.qt.io/qt-6/qqmlengine.html#contextForObject

        **[static] QQmlContext *QQmlEngine::contextForObject(const QObject *
        object )**

        Returns the **QQmlContext**  for the **object** , or 0 if no context has
        been set.

        When the **QQmlEngine**  instantiates a **QObject** , the context is set
        automatically.

        **See also** **setContextForObject** (), **qmlContext** (), and
        **qmlEngine** ().
        """
        ...

    def setOutputWarningsToStandardError(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#setOutputWarningsToStandardError

        **void QQmlEngine::setOutputWarningsToStandardError(bool enabled )**

        Set whether warning messages will be output to stderr to **enabled**.

        If **enabled** is true, any warning messages generated by QML will be
        output to stderr and emitted by the **warnings** () signal. If
        **enabled** is false, only the **warnings** () signal will be emitted.
        This allows applications to handle warning output themselves.

        The default value is true.

        **See also** **outputWarningsToStandardError** ().
        """
        ...

    def outputWarningsToStandardError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#outputWarningsToStandardError

        **bool QQmlEngine::outputWarningsToStandardError() const**

        Returns true if warning messages will be output to stderr in addition to
        being emitted by the **warnings** () signal, otherwise false.

        The default value is true.

        **See also** **setOutputWarningsToStandardError** ().
        """
        ...

    def setBaseUrl(self, a0: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#setBaseUrl

        **void QQmlEngine::setBaseUrl(const QUrl & url )**

        Set the base URL for this engine to **url**.

        **See also** **baseUrl** ().
        """
        ...

    def baseUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#baseUrl

        **QUrl QQmlEngine::baseUrl() const**

        Return the base URL for this engine. The base URL is only used to
        resolve components when a relative URL is passed to the
        **QQmlComponent**  constructor.

        If a base URL has not been explicitly set, this method returns the
        application's current working directory.

        **See also** **setBaseUrl** ().
        """
        ...

    def offlineStoragePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#offlineStoragePath-prop

        **offlineStoragePath : QString**

        This property holds the directory for storing offline user data

        Returns the directory where SQL and other offline storage is placed.

        The SQL databases created with `openDatabaseSync()` are stored here.

        The default is QML/OfflineStorage in the platform-standard user
        application data directory.

        Note that the path may not currently exist on the filesystem, so callers
        wanting to **create** new files at this location should create it first
        - see **QDir::mkpath** ().

        **Access functions:**

        QString **offlineStoragePath** () const
        void **setOfflineStoragePath**
        (const QString & **dir** )

        **See also**  l{Qt Quick Local Storage QML Types}.

        **Member Function Documentation**
        """
        ...

    def setOfflineStoragePath(self, dir: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#offlineStoragePath-prop

        **offlineStoragePath : QString**

        This property holds the directory for storing offline user data

        Returns the directory where SQL and other offline storage is placed.

        The SQL databases created with `openDatabaseSync()` are stored here.

        The default is QML/OfflineStorage in the platform-standard user
        application data directory.

        Note that the path may not currently exist on the filesystem, so callers
        wanting to **create** new files at this location should create it first
        - see **QDir::mkpath** ().

        **Access functions:**

        QString **offlineStoragePath** () const
        void **setOfflineStoragePath**
        (const QString & **dir** )

        **See also**  l{Qt Quick Local Storage QML Types}.

        **Member Function Documentation**
        """
        ...

    def incubationController(self) -> "QQmlIncubationController":
        """
        https://doc.qt.io/qt-6/qqmlengine.html#incubationController

        **QQmlIncubationController *QQmlEngine::incubationController() const**

        Returns the currently set incubation controller, or 0 if no controller
        has been set.

        **See also** **setIncubationController** ().
        """
        ...

    def setIncubationController(self, a0: "QQmlIncubationController") -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#setIncubationController

        **void QQmlEngine::setIncubationController(QQmlIncubationController *
        controller )**

        Sets the engine's incubation **controller**. The engine can only have
        one active controller and it does not take ownership of it.

        **See also** **incubationController** ().
        """
        ...

    def removeImageProvider(self, id: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#removeImageProvider

        **void QQmlEngine::removeImageProvider(const QString & providerId )**

        Removes the image provider for **providerId**.

        **See also** **addImageProvider** () and **QQuickImageProvider** .
        """
        ...

    def imageProvider(self, id: str) -> "QQmlImageProviderBase":
        """
        https://doc.qt.io/qt-6/qqmlengine.html#imageProvider

        **QQmlImageProviderBase *QQmlEngine::imageProvider(const QString &
        providerId ) const**

        Returns the image provider set for **providerId** if found; otherwise
        returns `nullptr`.

        **See also** **QQuickImageProvider** .
        """
        ...

    def addImageProvider(self, id: str, a1: "QQmlImageProviderBase") -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#addImageProvider

        **void QQmlEngine::addImageProvider(const QString & providerId ,
        QQmlImageProviderBase * provider )**

        Sets the **provider** to use for images requested via the **image** :
        url scheme, with host **providerId**. The **QQmlEngine**  takes
        ownership of **provider**.

        Image providers enable support for pixmap and threaded image requests.
        See the **QQuickImageProvider**  documentation for details on
        implementing and using image providers.

        All required image providers should be added to the engine before any
        QML sources files are loaded.

        **See also** **removeImageProvider** (), **QQuickImageProvider** , and
        **QQmlImageProviderBase** .
        """
        ...

    def networkAccessManager(self) -> QtNetwork.QNetworkAccessManager:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#networkAccessManager

        **QNetworkAccessManager *QQmlEngine::networkAccessManager() const**

        Returns a common QNetworkAccessManager which can be used by any QML type
        instantiated by this engine.

        If a **QQmlNetworkAccessManagerFactory**  has been set and a
        QNetworkAccessManager has not yet been created, the
        **QQmlNetworkAccessManagerFactory**  will be used to create the
        QNetworkAccessManager; otherwise the returned QNetworkAccessManager will
        have no proxy or cache set.

        **See also** **setNetworkAccessManagerFactory** ().
        """
        ...

    def networkAccessManagerFactory(self) -> "QQmlNetworkAccessManagerFactory":
        """
        https://doc.qt.io/qt-6/qqmlengine.html#networkAccessManagerFactory

        **QQmlNetworkAccessManagerFactory
        *QQmlEngine::networkAccessManagerFactory() const**

        Returns the current **QQmlNetworkAccessManagerFactory** .

        **See also** **setNetworkAccessManagerFactory** ().
        """
        ...

    def setNetworkAccessManagerFactory(
        self, a0: "QQmlNetworkAccessManagerFactory"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#setNetworkAccessManagerFactory

        **void QQmlEngine::setNetworkAccessManagerFactory(QQmlNetworkAccessManag
        erFactory * factory )**

        Sets the **factory** to use for creating QNetworkAccessManager(s).

        QNetworkAccessManager is used for all network access by QML. By
        implementing a factory it is possible to create custom
        QNetworkAccessManager with specialized caching, proxy and cookie
        support.

        The factory must be set before executing the engine.

        **Note:****QQmlEngine**  does not take ownership of the factory.

        **See also** **networkAccessManagerFactory** ().
        """
        ...

    def importPlugin(
        self, filePath: str, uri: str, errors: typing.Iterable["QQmlError"]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#importPlugin

        **bool QQmlEngine::importPlugin(const QString & filePath , const QString
        & uri , QList<QQmlError> * errors )**

        Imports the plugin named **filePath** with the **uri** provided. Returns
        true if the plugin was successfully imported; otherwise returns false.

        On failure and if non-null, the **errors** list will have any errors
        which occurred prepended to it.

        The plugin has to be a Qt plugin which implements the
        **QQmlEngineExtensionPlugin**  interface.
        """
        ...

    def addPluginPath(self, dir: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#addPluginPath

        **void QQmlEngine::addPluginPath(const QString & path )**

        Adds **path** as a directory where the engine searches for native
        plugins for imported modules (referenced in the `qmldir` file).

        By default, the list contains only `.`, i.e. the engine searches in the
        directory of the `qmldir` file itself.

        The newly added **path** will be first in the **pluginPathList** ().

        **See also** **setPluginPathList** ().
        """
        ...

    def setPluginPathList(self, paths: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#setPluginPathList

        **void QQmlEngine::setPluginPathList(const QStringList & paths )**

        Sets the list of directories where the engine searches for native
        plugins for imported modules (referenced in the `qmldir` file) to
        **paths**.

        By default, the list contains only `.`, i.e. the engine searches in the
        directory of the `qmldir` file itself.

        **See also** **pluginPathList** () and **addPluginPath** ().
        """
        ...

    def pluginPathList(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#pluginPathList

        **QStringList QQmlEngine::pluginPathList() const**

        Returns the list of directories where the engine searches for native
        plugins for imported modules (referenced in the `qmldir` file).

        By default, the list contains only `.`, i.e. the engine searches in the
        directory of the `qmldir` file itself.

        **See also** **addPluginPath** () and **setPluginPathList** ().
        """
        ...

    def addImportPath(self, dir: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#addImportPath

        **void QQmlEngine::addImportPath(const QString & path )**

        Adds **path** as a directory where the engine searches for installed
        modules in a URL-based directory structure.

        The **path** may be a local filesystem directory, a **Qt Resource**
        path (`:/imports`), a **Qt Resource**  url (`qrc:/imports`) or a URL.

        The **path** will be converted into canonical form before it is added to
        the import path list.

        The newly added **path** will be first in the **importPathList** ().

        **See also** **setImportPathList** () and **QML Modules** .
        """
        ...

    def setImportPathList(self, paths: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#setImportPathList

        **void QQmlEngine::setImportPathList(const QStringList & paths )**

        Sets **paths** as the list of directories where the engine searches for
        installed modules in a URL-based directory structure.

        By default, the list contains the directory of the application
        executable, paths specified in the `QML_IMPORT_PATH` environment
        variable, and the builtin `QmlImportsPath` from **QLibraryInfo** .

        **See also** **importPathList** () and **addImportPath** ().
        """
        ...

    def importPathList(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#importPathList

        **QStringList QQmlEngine::importPathList() const**

        Returns the list of directories where the engine searches for installed
        modules in a URL-based directory structure.

        For example, if `/opt/MyApp/lib/imports` is in the path, then QML that
        imports `com.mycompany.Feature` will cause the **QQmlEngine**  to look
        in `/opt/MyApp/lib/imports/com/mycompany/Feature/` for the components
        provided by that module. A `qmldir` file is required for defining the
        type version mapping and possibly QML extensions plugins.

        By default, the list contains the directory of the application
        executable, paths specified in the `QML_IMPORT_PATH` environment
        variable, and the builtin `QmlImportsPath` from **QLibraryInfo** .

        **See also** **addImportPath** () and **setImportPathList** ().
        """
        ...

    def trimComponentCache(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#trimComponentCache

        **void QQmlEngine::trimComponentCache()**

        Trims the engine's internal component cache.

        This function causes the property metadata of any loaded components
        which are not currently in use to be destroyed.

        A component is considered to be in use if there are any extant instances
        of the component itself, any instances of other components that use the
        component, or any objects instantiated by any of those components.

        **See also** **clearComponentCache** ().
        """
        ...

    def clearComponentCache(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#clearComponentCache

        **void QQmlEngine::clearComponentCache()**

        Clears the engine's internal component cache.

        This function causes the property metadata of all components previously
        loaded by the engine to be destroyed. All previously loaded components
        and the property bindings for all extant objects created from those
        components will cease to function.

        This function returns the engine to a state where it does not contain
        any loaded component data. This may be useful in order to reload a
        smaller subset of the previous component set, or to load a new version
        of a previously loaded component.

        Once the component cache has been cleared, components must be loaded
        before any new objects can be created.

        **Note:** Any existing objects created from QML components retain their
        types, even if you clear the component cache. This includes singleton
        objects. If you create more objects from the same QML code after
        clearing the cache, the new objects will be of different types than the
        old ones. Assigning such a new object to a property of its declared type
        belonging to an object created before clearing the cache won't work.

        As a general rule of thumb, make sure that no objects created from QML
        components are alive when you clear the component cache.

        **See also** **trimComponentCache** ().
        """
        ...

    def rootContext(self) -> "QQmlContext":
        """
        https://doc.qt.io/qt-6/qqmlengine.html#rootContext

        **QQmlContext *QQmlEngine::rootContext() const**

        Returns the engine's root context.

        The root context is automatically created by the **QQmlEngine** . Data
        that should be available to all QML component instances instantiated by
        the engine should be put in the root context.

        Additional data that should only be available to a subset of component
        instances should be added to sub-contexts parented to the root context.
        """
        ...

    @property
    def exit(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#exit

        **[signal, since 5.8] void QQmlEngine::exit(int retCode )**

        This signal is emitted when the QML loaded by the engine would like to
        exit from the event loop with the specified return code **retCode**.

        This function was introduced in Qt 5.8.

        **See also** **quit** ().
        """
        ...

    @property
    def quit(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#quit

        **[signal] void QQmlEngine::quit()**

        This signal is emitted when the QML loaded by the engine would like to
        quit.

        **See also** **exit** ().
        """
        ...

    @property
    def warnings(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qqmlengine.html#warnings

        **[signal] void QQmlEngine::warnings(const QList<QQmlError> & warnings
        )**

        This signal is emitted when **warnings** messages are generated by QML.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtRemoteObjects import *
import enum


class QRemoteObjectNode(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qremoteobjectnode.html

    **Detailed Description**

    The QRemoteObjectNode class provides an entry point to a **QtRemoteObjects**
    network. A network can be as simple as two nodes, or an arbitrarily complex
    set of processes and devices.

    A QRemoteObjectNode does not have a url that other nodes can connect to, and
    thus is able to acquire replicas only. It is not able to share source
    objects (only **QRemoteObjectHost**  and **QRemoteObjectRegistryHost**
    Nodes can share).

    Nodes may connect to each other directly using **connectToNode** , or they
    can use the **QRemoteObjectRegistry**  to simplify connections.

    The **QRemoteObjectRegistry**  is a special replica available to every node
    that connects to the Registry Url. It knows how to connect to every
    QRemoteObjectSource object on the network.

    **See also** **QRemoteObjectHost**  and **QRemoteObjectRegistryHost** .
    """

    class ErrorCode(enum.Enum):
        NoError: QRemoteObjectNode = ...
        RegistryNotAcquired: QRemoteObjectNode = ...
        RegistryAlreadyHosted: QRemoteObjectNode = ...
        NodeIsNoServer: QRemoteObjectNode = ...
        ServerAlreadyCreated: QRemoteObjectNode = ...
        UnintendedRegistryHosting: QRemoteObjectNode = ...
        OperationNotValidOnClientNode: QRemoteObjectNode = ...
        SourceNotRegistered: QRemoteObjectNode = ...
        MissingObjectName: QRemoteObjectNode = ...
        HostUrlInvalid: QRemoteObjectNode = ...
        ProtocolMismatch: QRemoteObjectNode = ...
        ListenFailed: QRemoteObjectNode = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#QRemoteObjectNode

        **QRemoteObjectNode::QRemoteObjectNode(QObject * parent = nullptr)**

        Default constructor for QRemoteObjectNode with the given **parent**. A
        Node constructed in this manner can not be connected to, and thus can
        not expose Source objects on the network. It also will not include a
        **QRemoteObjectRegistry** , unless set manually using **setRegistryUrl**
        .

        **See also** **connectToNode**  and **setRegistryUrl** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        registryAddress: QtCore.QUrl,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#QRemoteObjectNode-1

        **QRemoteObjectNode::QRemoteObjectNode(const QUrl & registryAddress ,
        QObject * parent = nullptr)**

        QRemoteObjectNode connected to a {**QRemoteObjectRegistry** }
        {Registry}. A Node constructed in this manner can not be connected to,
        and thus can not expose Source objects on the network. Finding and
        connecting to other (Host) Nodes is handled by the
        **QRemoteObjectRegistry**  specified by **registryAddress**.

        **See also** **connectToNode** , **setRegistryUrl** ,
        **QRemoteObjectHost** , and **QRemoteObjectRegistryHost** .
        """
        ...

    def timerEvent(self, a0: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#timerEvent

        **[override virtual protected] void
        QRemoteObjectNode::timerEvent(QTimerEvent *)**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def error(self, errorCode: "QRemoteObjectNode.ErrorCode") -> None:
        ...

    def setHeartbeatInterval(self, interval: int) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#heartbeatInterval-prop

        **heartbeatInterval : int**

        Heartbeat interval in ms.

        The heartbeat (only helpful for socket connections) will periodically
        send a message to connected nodes to detect whether the connection was
        disrupted. Qt Remote Objects will try to reconnect automatically if it
        detects a dropped connection. This function can help with that detection
        since the client will only detect that the server is unavailable when it
        tries to send data.

        A value of `0` (the default) will disable the heartbeat.

        **Access functions:**

        int **heartbeatInterval** () const
        void **setHeartbeatInterval** (int
        **interval** )

        **Notifier signal:**

        void **heartbeatIntervalChanged** (int **heartbeatInterval** )
        """
        ...

    def heartbeatInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#heartbeatInterval-prop

        **heartbeatInterval : int**

        Heartbeat interval in ms.

        The heartbeat (only helpful for socket connections) will periodically
        send a message to connected nodes to detect whether the connection was
        disrupted. Qt Remote Objects will try to reconnect automatically if it
        detects a dropped connection. This function can help with that detection
        since the client will only detect that the server is unavailable when it
        tries to send data.

        A value of `0` (the default) will disable the heartbeat.

        **Access functions:**

        int **heartbeatInterval** () const
        void **setHeartbeatInterval** (int
        **interval** )

        **Notifier signal:**

        void **heartbeatIntervalChanged** (int **heartbeatInterval** )
        """
        ...

    def lastError(self) -> "QRemoteObjectNode.ErrorCode":
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#lastError

        **QRemoteObjectNode::ErrorCode QRemoteObjectNode::lastError() const**

        Returns the last error set.
        """
        ...

    def setPersistedStore(
        self, persistedStore: QRemoteObjectAbstractPersistedStore
    ) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#persistedStore-prop

        **[since 5.11] persistedStore : QRemoteObjectAbstractPersistedStore***

        Allows setting a **QRemoteObjectAbstractPersistedStore**  instance for
        the node.

        Allows replica **PROP**  members with the PERSISTED trait to save their
        current value when the replica is deleted and restore a stored value the
        next time the replica is started.

        Requires a **QRemoteObjectAbstractPersistedStore**  class implementation
        to control where and how persistence is handled.

        This property was introduced in Qt 5.11.

        **Access functions:**

        QRemoteObjectAbstractPersistedStore * **persistedStore** () const
        void
        **setPersistedStore** (QRemoteObjectAbstractPersistedStore *
        **persistedStore** )
        """
        ...

    def persistedStore(self) -> QRemoteObjectAbstractPersistedStore:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#persistedStore-prop

        **[since 5.11] persistedStore : QRemoteObjectAbstractPersistedStore***

        Allows setting a **QRemoteObjectAbstractPersistedStore**  instance for
        the node.

        Allows replica **PROP**  members with the PERSISTED trait to save their
        current value when the replica is deleted and restore a stored value the
        next time the replica is started.

        Requires a **QRemoteObjectAbstractPersistedStore**  class implementation
        to control where and how persistence is handled.

        This property was introduced in Qt 5.11.

        **Access functions:**

        QRemoteObjectAbstractPersistedStore * **persistedStore** () const
        void
        **setPersistedStore** (QRemoteObjectAbstractPersistedStore *
        **persistedStore** )
        """
        ...

    def registry(self) -> "QRemoteObjectRegistry":
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#registry

        **const QRemoteObjectRegistry *QRemoteObjectNode::registry() const**

        Returns a pointer to the Node's **QRemoteObjectRegistry** , if the Node
        is using the Registry feature; otherwise it returns `nullptr`.
        """
        ...

    def waitForRegistry(self, timeout: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#waitForRegistry

        **bool QRemoteObjectNode::waitForRegistry(int timeout = 30000)**

        Blocks until this Node's **Registry**  is initialized or **timeout** (in
        milliseconds) expires. Returns `true` if the **Registry**  is
        successfully initialized upon return, or `false` otherwise.
        """
        ...

    def setRegistryUrl(self, registryAddress: QtCore.QUrl) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#registryUrl-prop

        **registryUrl : QUrl**

        This property holds the address of the **Registry**  used by this node.

        This is an empty **QUrl**  if there is no registry in use.

        **Access functions:**

        QUrl **registryUrl** () const
        virtual bool **setRegistryUrl** (const
        QUrl & **registryAddress** )

        **Member Function Documentation**
        """
        ...

    def registryUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#registryUrl-prop

        **registryUrl : QUrl**

        This property holds the address of the **Registry**  used by this node.

        This is an empty **QUrl**  if there is no registry in use.

        **Access functions:**

        QUrl **registryUrl** () const
        virtual bool **setRegistryUrl** (const
        QUrl & **registryAddress** )

        **Member Function Documentation**
        """
        ...

    def acquireModel(
        self,
        name: str,
        action: QtRemoteObjects.InitialAction = ...,
        rolesHint: typing.Iterable[int] = ...,
    ) -> QAbstractItemModelReplica:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#acquireModel

        **QAbstractItemModelReplica *QRemoteObjectNode::acquireModel(const
        QString & name , QtRemoteObjects::InitialAction action =
        QtRemoteObjects::FetchRootSize, const QList<int> & rolesHint = {})**

        Returns a pointer to a **Replica**  which is specifically derived from
        **QAbstractItemModel** . The **name** provided must match the name used
        with the matching **enableRemoting**  that put the **Model**  on the
        network. **action** specifies whether the model should fetch data before
        the **initialized**  signal is emitted. If it's set to
        **QtRemoteObjects::PrefetchData** , then the data for roles in the
        **rolesHint** will be prefetched. If **rolesHint** is empty, then the
        data for all the roles exposed by **Source**  will be prefetched.

        The returned model will be empty until it is initialized with the
        **Source** .
        """
        ...

    def acquireDynamic(self, name: str) -> QRemoteObjectDynamicReplica:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#acquireDynamic

        **QRemoteObjectDynamicReplica *QRemoteObjectNode::acquireDynamic(const
        QString & name )**

        Returns a **QRemoteObjectDynamicReplica**  of the Source **name**.
        """
        ...

    def instances(self, typeName: str) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#instances

        **template <typename T> QStringList QRemoteObjectNode::instances()
        const**

        This templated function (taking a **repc**  generated type as the
        template parameter) will return the list of names of every instance of
        that type on the Remote Objects network. For example, if you have a
        Shape class defined in a .rep file, and Circle and Square classes
        inherit from the Source definition, they can be shared on the Remote
        Objects network using **enableRemoting** .

        Square square;
            Circle circle;
            myHost.enableRemoting(&square,
        "Square");
            myHost.enableRemoting(&circle, "Circle");

        Then instance can be used to find the available instances of Shape.

        **QStringList**  instances = clientNode.instances<Shape>();
            // will
        return a QStringList containing "Circle" and "Square"
            auto instance1
        = clientNode.acquire<Shape>("Circle");
            auto instance2 =
        clientNode.acquire<Shape>("Square");
            ...
        """
        ...

    def setName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#setName

        **[virtual] void QRemoteObjectNode::setName(const QString & name )**

        Sets **name** as the internal name for this Node. This is then output as
        part of the logging (if enabled). This is primarily useful if you merge
        log data from multiple nodes.
        """
        ...

    def addClientSideConnection(self, ioDevice: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#addClientSideConnection

        **[since 5.12] void QRemoteObjectNode::addClientSideConnection(QIODevice
        * ioDevice )**

        In order to **QRemoteObjectNode::acquire** () **Replica**  objects over
        **External QIODevices** , Qt Remote Objects needs access to the
        communications channel (a **QIODevice** ) between the respective nodes.
        It is the addClientSideConnection() call that enables this, taking the
        **ioDevice** as input. Any **acquire** () call made without calling
        addClientSideConnection will still work, but the Node will not be able
        to initialize the **Replica**  without being provided the connection to
        the Host node.

        This function was introduced in Qt 5.12.

        **See also** **QRemoteObjectHostBase::addHostSideConnection** .
        """
        ...

    def connectToNode(self, address: QtCore.QUrl) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#connectToNode

        **[invokable] bool QRemoteObjectNode::connectToNode(const QUrl & address
        )**

        Connects a client node to the host node at **address**.

        Connections will remain valid until the host node is deleted or no
        longer accessible over a network.

        Once a client is connected to a host, valid Replicas can then be
        acquired if the corresponding Source is being remoted.

        Return `true` on success, `false` otherwise (usually an unrecognized
        url, or connecting to already connected address).

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @property
    def heartbeatIntervalChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def remoteObjectAdded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#remoteObjectAdded

        **[signal] void QRemoteObjectNode::remoteObjectAdded(const
        QRemoteObjectSourceLocation & loc )**

        This signal is emitted whenever a new **Source**  object is added to the
        Registry. The signal will not be emitted if there is no Registry set
        (i.e., Sources over connections made via **connectToNode**  directly).
        The **loc** parameter contains the information about the added Source,
        including name, type and the **QUrl**  of the hosting Node.

        **See also** **remoteObjectRemoved** () and **instances** ().
        """
        ...

    @property
    def remoteObjectRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qremoteobjectnode.html#remoteObjectRemoved

        **[signal] void QRemoteObjectNode::remoteObjectRemoved(const
        QRemoteObjectSourceLocation & loc )**

        This signal is emitted whenever a known **Source**  object is removed
        from the Registry. The signal will not be emitted if there is no
        Registry set (i.e., Sources over connections made via **connectToNode**
        directly). The **loc** parameter contains the information about the
        removed Source, including name, type and the **QUrl**  of the hosting
        Node.

        **See also** **remoteObjectAdded**  and **instances** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtXml import *
import enum


class QDomImplementation(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdomimplementation.html

    **Detailed Description**

    This class describes the features that are supported by the DOM
    implementation. Currently the XML subset of DOM Level 1 and DOM Level 2 Core
    are supported.

    Normally you will use the function **QDomDocument::implementation** () to
    get the implementation object.

    You can create a new document type with **createDocumentType** () and a new
    document with **createDocument** ().

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.

    The QDom classes have a few issues of nonconformance with the XML
    specifications that cannot be fixed in Qt 4 without breaking backward
    compatibility. The Qt XML Patterns module and the **QXmlStreamReader**  and
    **QXmlStreamWriter**  classes have a higher degree of a conformance.

    **See also** **hasFeature** ().
    """

    class InvalidDataPolicy(enum.Enum):
        AcceptInvalidChars: QDomImplementation = ...
        DropInvalidChars: QDomImplementation = ...
        ReturnNullNode: QDomImplementation = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomimplementation.html#QDomImplementation

        **QDomImplementation::QDomImplementation()**

        Constructs a QDomImplementation object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDomImplementation") -> None:
        """
        https://doc.qt.io/qt-6/qdomimplementation.html#QDomImplementation-1

        **QDomImplementation::QDomImplementation(const QDomImplementation & x
        )**

        Constructs a copy of **x**.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomimplementation.html#isNull

        **bool QDomImplementation::isNull()**

        Returns `false` if the object was created by
        **QDomDocument::implementation** (); otherwise returns `true`.
        """
        ...

    @staticmethod
    def setInvalidDataPolicy(policy: "QDomImplementation.InvalidDataPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qdomimplementation.html#setInvalidDataPolicy

        **[static] void QDomImplementation::setInvalidDataPolicy(QDomImplementat
        ion::InvalidDataPolicy policy )**

        Sets the invalid data policy, which specifies what should be done when a
        factory function in **QDomDocument**  is passed invalid data.

        The **policy** is set for all instances of **QDomDocument**  which
        already exist and which will be created in the future.

        void XML_snippet_main()
            {
            **QDomDocument**  doc;
        **QDomImplementation**  impl;
            // This will create the element, but
        the resulting XML document will
            // be invalid, because '~' is not a
        valid character in a tag name.
        impl.setInvalidDataPolicy(**QDomImplementation** ::AcceptInvalidChars);
        **QDomElement**  elt1 = doc.createElement("foo~bar");

            // This
        will create an element with the tag name "foobar".
        impl.setInvalidDataPolicy(**QDomImplementation** ::DropInvalidChars);
        **QDomElement**  elt2 = doc.createElement("foo~bar");

            // This
        will create a null element.
        impl.setInvalidDataPolicy(**QDomImplementation** ::ReturnNullNode);
        **QDomElement**  elt3 = doc.createElement("foo~bar");
            }

        **Warning:** This function is not **reentrant** .

        **See also** **invalidDataPolicy** () and **InvalidDataPolicy** .
        """
        ...

    @staticmethod
    def invalidDataPolicy() -> "QDomImplementation.InvalidDataPolicy":
        """
        https://doc.qt.io/qt-6/qdomimplementation.html#invalidDataPolicy

        **[static] QDomImplementation::InvalidDataPolicy
        QDomImplementation::invalidDataPolicy()**

        Returns the invalid data policy, which specifies what should be done
        when a factory function in **QDomDocument**  is passed invalid data.

        **Warning:** This function is not **reentrant** .

        **See also** **setInvalidDataPolicy** () and **InvalidDataPolicy** .
        """
        ...

    def createDocument(
        self, nsURI: str, qName: str, doctype: "QDomDocumentType"
    ) -> "QDomDocument":
        """
        https://doc.qt.io/qt-6/qdomimplementation.html#createDocument

        **QDomDocument QDomImplementation::createDocument(const QString & nsURI
        , const QString & qName , const QDomDocumentType & doctype )**

        Creates a DOM document with the document type **doctype**. This function
        also adds a root element node with the qualified name **qName** and the
        namespace URI **nsURI**.
        """
        ...

    def createDocumentType(
        self, qName: str, publicId: str, systemId: str
    ) -> "QDomDocumentType":
        """
        https://doc.qt.io/qt-6/qdomimplementation.html#createDocumentType

        **QDomDocumentType QDomImplementation::createDocumentType(const QString
        & qName , const QString & publicId , const QString & systemId )**

        Creates a document type node for the name **qName**.

        **publicId** specifies the public identifier of the external subset. If
        you specify an empty string (QString()) as the **publicId** , this means
        that the document type has no public identifier.

        **systemId** specifies the system identifier of the external subset. If
        you specify an empty string as the **systemId** , this means that the
        document type has no system identifier.

        Since you cannot have a public identifier without a system identifier,
        the public identifier is set to an empty string if there is no system
        identifier.

        DOM level 2 does not support any other document type declaration
        features.

        The only way you can use a document type that was created this way, is
        in combination with the **createDocument** () function to create a
        **QDomDocument**  with this document type.

        In the DOM specification, this is the only way to create a non-null
        document. For historical reasons, Qt also allows to create the document
        using the default empty constructor. The resulting document is null, but
        becomes non-null when a factory function, for example
        **QDomDocument::createElement** (), is called. The document also becomes
        non-null when setContent() is called.

        **See also** **createDocument** ().
        """
        ...

    def hasFeature(self, feature: str, version: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdomimplementation.html#hasFeature

        **bool QDomImplementation::hasFeature(const QString & feature , const
        QString & version ) const**

        The function returns `true` if QDom implements the requested **version**
        of a **feature** ; otherwise returns `false`.

        The currently supported features and their versions:

        FeatureVersion
        XML1.0
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QBluetoothDeviceInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html

    **Detailed Description**

    QBluetoothDeviceInfo provides information about a Bluetooth device's name,
    address and class of device.
    """

    class Field(enum.Flag):
        None_: QBluetoothDeviceInfo = ...
        RSSI: QBluetoothDeviceInfo = ...
        ManufacturerData: QBluetoothDeviceInfo = ...
        All: QBluetoothDeviceInfo = ...

    class CoreConfiguration(enum.Flag):
        UnknownCoreConfiguration: QBluetoothDeviceInfo = ...
        LowEnergyCoreConfiguration: QBluetoothDeviceInfo = ...
        BaseRateCoreConfiguration: QBluetoothDeviceInfo = ...
        BaseRateAndLowEnergyCoreConfiguration: QBluetoothDeviceInfo = ...

    class ServiceClass(enum.Flag):
        NoService: QBluetoothDeviceInfo = ...
        PositioningService: QBluetoothDeviceInfo = ...
        NetworkingService: QBluetoothDeviceInfo = ...
        RenderingService: QBluetoothDeviceInfo = ...
        CapturingService: QBluetoothDeviceInfo = ...
        ObjectTransferService: QBluetoothDeviceInfo = ...
        AudioService: QBluetoothDeviceInfo = ...
        TelephonyService: QBluetoothDeviceInfo = ...
        InformationService: QBluetoothDeviceInfo = ...
        AllServices: QBluetoothDeviceInfo = ...

    class MinorHealthClass(enum.Enum):
        UncategorizedHealthDevice: QBluetoothDeviceInfo = ...
        HealthBloodPressureMonitor: QBluetoothDeviceInfo = ...
        HealthThermometer: QBluetoothDeviceInfo = ...
        HealthWeightScale: QBluetoothDeviceInfo = ...
        HealthGlucoseMeter: QBluetoothDeviceInfo = ...
        HealthPulseOximeter: QBluetoothDeviceInfo = ...
        HealthDataDisplay: QBluetoothDeviceInfo = ...
        HealthStepCounter: QBluetoothDeviceInfo = ...

    class MinorToyClass(enum.Enum):
        UncategorizedToy: QBluetoothDeviceInfo = ...
        ToyRobot: QBluetoothDeviceInfo = ...
        ToyVehicle: QBluetoothDeviceInfo = ...
        ToyDoll: QBluetoothDeviceInfo = ...
        ToyController: QBluetoothDeviceInfo = ...
        ToyGame: QBluetoothDeviceInfo = ...

    class MinorWearableClass(enum.Enum):
        UncategorizedWearableDevice: QBluetoothDeviceInfo = ...
        WearableWristWatch: QBluetoothDeviceInfo = ...
        WearablePager: QBluetoothDeviceInfo = ...
        WearableJacket: QBluetoothDeviceInfo = ...
        WearableHelmet: QBluetoothDeviceInfo = ...
        WearableGlasses: QBluetoothDeviceInfo = ...

    class MinorImagingClass(enum.Enum):
        UncategorizedImagingDevice: QBluetoothDeviceInfo = ...
        ImageDisplay: QBluetoothDeviceInfo = ...
        ImageCamera: QBluetoothDeviceInfo = ...
        ImageScanner: QBluetoothDeviceInfo = ...
        ImagePrinter: QBluetoothDeviceInfo = ...

    class MinorPeripheralClass(enum.Enum):
        UncategorizedPeripheral: QBluetoothDeviceInfo = ...
        KeyboardPeripheral: QBluetoothDeviceInfo = ...
        PointingDevicePeripheral: QBluetoothDeviceInfo = ...
        KeyboardWithPointingDevicePeripheral: QBluetoothDeviceInfo = ...
        JoystickPeripheral: QBluetoothDeviceInfo = ...
        GamepadPeripheral: QBluetoothDeviceInfo = ...
        RemoteControlPeripheral: QBluetoothDeviceInfo = ...
        SensingDevicePeripheral: QBluetoothDeviceInfo = ...
        DigitizerTabletPeripheral: QBluetoothDeviceInfo = ...
        CardReaderPeripheral: QBluetoothDeviceInfo = ...

    class MinorAudioVideoClass(enum.Enum):
        UncategorizedAudioVideoDevice: QBluetoothDeviceInfo = ...
        WearableHeadsetDevice: QBluetoothDeviceInfo = ...
        HandsFreeDevice: QBluetoothDeviceInfo = ...
        Microphone: QBluetoothDeviceInfo = ...
        Loudspeaker: QBluetoothDeviceInfo = ...
        Headphones: QBluetoothDeviceInfo = ...
        PortableAudioDevice: QBluetoothDeviceInfo = ...
        CarAudio: QBluetoothDeviceInfo = ...
        SetTopBox: QBluetoothDeviceInfo = ...
        HiFiAudioDevice: QBluetoothDeviceInfo = ...
        Vcr: QBluetoothDeviceInfo = ...
        VideoCamera: QBluetoothDeviceInfo = ...
        Camcorder: QBluetoothDeviceInfo = ...
        VideoMonitor: QBluetoothDeviceInfo = ...
        VideoDisplayAndLoudspeaker: QBluetoothDeviceInfo = ...
        VideoConferencing: QBluetoothDeviceInfo = ...
        GamingDevice: QBluetoothDeviceInfo = ...

    class MinorNetworkClass(enum.Enum):
        NetworkFullService: QBluetoothDeviceInfo = ...
        NetworkLoadFactorOne: QBluetoothDeviceInfo = ...
        NetworkLoadFactorTwo: QBluetoothDeviceInfo = ...
        NetworkLoadFactorThree: QBluetoothDeviceInfo = ...
        NetworkLoadFactorFour: QBluetoothDeviceInfo = ...
        NetworkLoadFactorFive: QBluetoothDeviceInfo = ...
        NetworkLoadFactorSix: QBluetoothDeviceInfo = ...
        NetworkNoService: QBluetoothDeviceInfo = ...

    class MinorPhoneClass(enum.Enum):
        UncategorizedPhone: QBluetoothDeviceInfo = ...
        CellularPhone: QBluetoothDeviceInfo = ...
        CordlessPhone: QBluetoothDeviceInfo = ...
        SmartPhone: QBluetoothDeviceInfo = ...
        WiredModemOrVoiceGatewayPhone: QBluetoothDeviceInfo = ...
        CommonIsdnAccessPhone: QBluetoothDeviceInfo = ...

    class MinorComputerClass(enum.Enum):
        UncategorizedComputer: QBluetoothDeviceInfo = ...
        DesktopComputer: QBluetoothDeviceInfo = ...
        ServerComputer: QBluetoothDeviceInfo = ...
        LaptopComputer: QBluetoothDeviceInfo = ...
        HandheldClamShellComputer: QBluetoothDeviceInfo = ...
        HandheldComputer: QBluetoothDeviceInfo = ...
        WearableComputer: QBluetoothDeviceInfo = ...

    class MinorMiscellaneousClass(enum.Enum):
        UncategorizedMiscellaneous: QBluetoothDeviceInfo = ...

    class MajorDeviceClass(enum.Enum):
        MiscellaneousDevice: QBluetoothDeviceInfo = ...
        ComputerDevice: QBluetoothDeviceInfo = ...
        PhoneDevice: QBluetoothDeviceInfo = ...
        NetworkDevice: QBluetoothDeviceInfo = ...
        AudioVideoDevice: QBluetoothDeviceInfo = ...
        PeripheralDevice: QBluetoothDeviceInfo = ...
        ImagingDevice: QBluetoothDeviceInfo = ...
        WearableDevice: QBluetoothDeviceInfo = ...
        ToyDevice: QBluetoothDeviceInfo = ...
        HealthDevice: QBluetoothDeviceInfo = ...
        UncategorizedDevice: QBluetoothDeviceInfo = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#QBluetoothDeviceInfo

        **QBluetoothDeviceInfo::QBluetoothDeviceInfo()**

        Constructs an invalid QBluetoothDeviceInfo object.
        """
        ...

    @typing.overload
    def __init__(
        self, address: QBluetoothAddress, name: str, classOfDevice: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#QBluetoothDeviceInfo-1

        **QBluetoothDeviceInfo::QBluetoothDeviceInfo(const QBluetoothAddress &
        address , const QString & name , quint32 classOfDevice )**

        Constructs a QBluetoothDeviceInfo object with Bluetooth address
        **address** , device name **name** and the encoded class of device
        **classOfDevice**.

        The **classOfDevice** parameter is encoded in the following format

        BitsSizeDescription
        0 - 12Unused, set to 0.
        2 - 76Minor device
        class.
        8 - 125Major device class.
        13 - 2311Service class.
        """
        ...

    @typing.overload
    def __init__(self, uuid: "QBluetoothUuid", name: str, classOfDevice: int) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#QBluetoothDeviceInfo-2

        **[since 5.5] QBluetoothDeviceInfo::QBluetoothDeviceInfo(const
        QBluetoothUuid & uuid , const QString & name , quint32 classOfDevice )**

        Constructs a QBluetoothDeviceInfo object with unique **uuid** , device
        name **name** and the encoded class of device **classOfDevice**.

        This constructor is required for Low Energy devices on macOS and iOS.
        CoreBluetooth API hides addresses and provides unique UUIDs to identify
        a device. This UUID is not the same thing as a service UUID and is
        required to work later with CoreBluetooth API and discovered devices.

        This function was introduced in Qt 5.5.
        """
        ...

    @typing.overload
    def __init__(self, other: "QBluetoothDeviceInfo") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#QBluetoothDeviceInfo-3

        **QBluetoothDeviceInfo::QBluetoothDeviceInfo(const QBluetoothDeviceInfo
        & other )**

        Constructs a QBluetoothDeviceInfo that is a copy of **other**.
        """
        ...

    def setName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#setName

        **[since 6.2] void QBluetoothDeviceInfo::setName(const QString & name
        )**

        Sets the **name** of the device.

        This function was introduced in Qt 6.2.

        **See also** **name** ().
        """
        ...

    def setManufacturerData(self, manufacturerId: int, data: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#setManufacturerData

        **[since 5.12] bool QBluetoothDeviceInfo::setManufacturerData(quint16
        manufacturerId , const QByteArray & data )**

        Sets the advertised manufacturer **data** for the given
        **manufacturerId**. Returns `true` if it was inserted, `false` if it was
        already known.

        Since Qt 5.14, different values for **data** and the same
        **manufacturerId** no longer replace each other but are accumulated for
        the duration of a device scan.

        This function was introduced in Qt 5.12.

        **See also** **manufacturerData** .
        """
        ...

    @typing.overload
    def manufacturerData(self) -> typing.Dict[int, QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#manufacturerData

        **[since 5.12] QByteArray QBluetoothDeviceInfo::manufacturerData(quint16
        manufacturerId ) const**

        Returns the data associated with the given **manufacturerId**.

        Manufacturer data is defined by the Supplement to the Bluetooth Core
        Specification and consists of two segments:

        * Manufacturer specific identifier code from the **Assigned Numbers**
        Company Identifiers document
          * Sequence of arbitrary data octets

        The interpretation of the data octets is defined by the manufacturer
        specified by the company identifier.

        **Note:** The remote device may provide multiple data entries per
        manufacturerId. This function only returns the first entry. If all
        entries are needed use **manufacturerData** () which returns a multi
        hash.

        This function was introduced in Qt 5.12.

        **See also** **manufacturerIds** () and **setManufacturerData** ().
        """
        ...

    @typing.overload
    def manufacturerData(self, manufacturerId: int) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#manufacturerData-1

        **[since 5.12] QMultiHash<quint16, QByteArray>
        QBluetoothDeviceInfo::manufacturerData() const**

        Returns the complete set of all manufacturer data.

        Some devices may provide multiple manufacturer data entries per
        manufacturer ID. An example might be a Bluetooth Low Energy device that
        sends a different manufacturer data via advertisement packets and scan
        response packets respectively. Therefore the returned hash table may
        have multiple entries per manufacturer ID or hash key.

        This function was introduced in Qt 5.12.

        **See also** **setManufacturerData** .
        """
        ...

    def manufacturerIds(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#manufacturerIds

        **[since 5.12] QList<quint16> QBluetoothDeviceInfo::manufacturerIds()
        const**

        Returns all manufacturer ids attached to this device information.

        This function was introduced in Qt 5.12.

        **See also** **manufacturerData** () and **setManufacturerData** ().
        """
        ...

    def deviceUuid(self) -> "QBluetoothUuid":
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#deviceUuid

        **[since 5.5] QBluetoothUuid QBluetoothDeviceInfo::deviceUuid() const**

        Returns a unique identifier for a Bluetooth device without an address.

        In general, this uuid is invalid on every platform but macOS and iOS. It
        is used as a workaround for those two platforms as they do not provide
        Bluetooth addresses for found Bluetooth Low Energy devices. Every other
        platform uses **address** () instead.

        This function was introduced in Qt 5.5.

        **See also** **setDeviceUuid** ().
        """
        ...

    def setDeviceUuid(self, uuid: "QBluetoothUuid") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#setDeviceUuid

        **[since 5.5] void QBluetoothDeviceInfo::setDeviceUuid(const
        QBluetoothUuid & uuid )**

        Sets the unique identifier **uuid** for Bluetooth devices, that do not
        have addresses. This happens on macOS and iOS, where the CoreBluetooth
        API hides addresses, but provides UUIDs to identify devices/peripherals.

        This uuid is invalid on any other platform.

        This function was introduced in Qt 5.5.

        **See also** **deviceUuid** ().
        """
        ...

    def coreConfigurations(self) -> "QBluetoothDeviceInfo.CoreConfiguration":
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#coreConfigurations

        **[since 5.4] QBluetoothDeviceInfo::CoreConfigurations
        QBluetoothDeviceInfo::coreConfigurations() const**

        Returns the configuration of the device. If device configuration is not
        set, basic rate device configuration will be returned.

        This function was introduced in Qt 5.4.

        **See also** **setCoreConfigurations** ().
        """
        ...

    def setCoreConfigurations(
        self, coreConfigs: "QBluetoothDeviceInfo.CoreConfiguration"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#setCoreConfigurations

        **[since 5.4] void QBluetoothDeviceInfo::setCoreConfigurations(QBluetoot
        hDeviceInfo::CoreConfigurations coreConfigs )**

        Sets the **CoreConfigurations**  of the device to **coreConfigs**. This
        will help to make a difference between regular and Low Energy devices.

        This function was introduced in Qt 5.4.

        **See also** **coreConfigurations** ().
        """
        ...

    def serviceUuids(self) -> typing.List["QBluetoothUuid"]:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#serviceUuids

        **[since 6.0] QList<QBluetoothUuid> QBluetoothDeviceInfo::serviceUuids()
        const**

        Returns the list of service UUIDS supported by the device. Most commonly
        this list of uuids represents custom uuids or a uuid value specified by
        **QBluetoothUuid::ServiceClassUuid** .

        This function was introduced in Qt 6.0.

        **See also** **setServiceUuids** () and serviceUuids().
        """
        ...

    def setServiceUuids(self, uuids: typing.Iterable["QBluetoothUuid"]) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#setServiceUuids

        **[since 5.13] void QBluetoothDeviceInfo::setServiceUuids(const
        QList<QBluetoothUuid> & uuids )**

        Sets the list of service UUIDs to **uuids**.

        This function was introduced in Qt 5.13.

        **See also** **serviceUuids** ().
        """
        ...

    def setRssi(self, signal: int) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#setRssi

        **void QBluetoothDeviceInfo::setRssi(qint16 signal )**

        Set the **signal** strength value, used internally.

        **See also** **rssi** ().
        """
        ...

    def rssi(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#rssi

        **qint16 QBluetoothDeviceInfo::rssi() const**

        Returns the signal strength when the device was last scanned

        **See also** **setRssi** ().
        """
        ...

    def minorDeviceClass(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#minorDeviceClass

        **quint8 QBluetoothDeviceInfo::minorDeviceClass() const**

        Returns the minor device class of the device. The actual information is
        context dependent on the value of **majorDeviceClass** ().

        **See also** **MinorAudioVideoClass** , **MinorComputerClass** ,
        **MinorHealthClass** , **MinorImagingClass** ,
        **MinorMiscellaneousClass** , **MinorNetworkClass** ,
        **MinorPeripheralClass** , **MinorPhoneClass** , **MinorToyClass** , and
        **MinorWearableClass** .
        """
        ...

    def majorDeviceClass(self) -> "QBluetoothDeviceInfo.MajorDeviceClass":
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#majorDeviceClass

        **QBluetoothDeviceInfo::MajorDeviceClass
        QBluetoothDeviceInfo::majorDeviceClass() const**

        Returns the major device class of the device.
        """
        ...

    def serviceClasses(self) -> "QBluetoothDeviceInfo.ServiceClass":
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#serviceClasses

        **QBluetoothDeviceInfo::ServiceClasses
        QBluetoothDeviceInfo::serviceClasses() const**

        Returns the service class of the device.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#name

        **QString QBluetoothDeviceInfo::name() const**

        Returns the name assigned to the device.

        **See also** **setName** ().
        """
        ...

    def address(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#address

        **QBluetoothAddress QBluetoothDeviceInfo::address() const**

        Returns the address of the device.

        **Note:** On iOS and macOS this address is invalid. Instead
        **deviceUuid** () should be used. Those two platforms do not expose
        Bluetooth addresses for found Bluetooth devices and utilize unique
        device identifiers.

        **See also** **deviceUuid** ().
        """
        ...

    def setCached(self, cached: bool) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#setCached

        **void QBluetoothDeviceInfo::setCached(bool cached )**

        Used by the system to set the **cached** flag if the
        **QBluetoothDeviceInfo**  is created from cached data. Cached
        information may not be as accurate as data read from an active device.

        **See also** **isCached** ().
        """
        ...

    def isCached(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#isCached

        **bool QBluetoothDeviceInfo::isCached() const**

        Returns true if the **QBluetoothDeviceInfo**  object is created from
        cached data.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothdeviceinfo.html#isValid

        **bool QBluetoothDeviceInfo::isValid() const**

        Returns true if the **QBluetoothDeviceInfo**  object is valid, otherwise
        returns false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QAudioDecoder(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qaudiodecoder.html

    **Detailed Description**

    The QAudioDecoder class is a high level class for decoding audio media
    files. It is similar to the **QMediaPlayer**  class except that audio is
    provided back through this API rather than routed directly to audio
    hardware.

    **See also** **QAudioBuffer** .
    """

    class Error(enum.Enum):
        NoError: QAudioDecoder = ...
        ResourceError: QAudioDecoder = ...
        FormatError: QAudioDecoder = ...
        AccessDeniedError: QAudioDecoder = ...
        NotSupportedError: QAudioDecoder = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#QAudioDecoder

        **QAudioDecoder::QAudioDecoder(QObject * parent = nullptr)**

        Construct an QAudioDecoder instance with **parent**.
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#stop

        **[slot] void QAudioDecoder::stop()**

        Stop decoding audio. Calling **start** () again will resume decoding
        from the beginning.
        """
        ...

    def start(self) -> None:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#start

        **[slot] void QAudioDecoder::start()**

        Starts decoding the audio resource.

        As data gets decoded, the **bufferReady** () signal will be emitted when
        enough data has been decoded. Calling **read** () will then return an
        audio buffer without blocking.

        If you call **read** () before a buffer is ready, an invalid buffer will
        be returned, again without blocking.

        **See also** **read** ().
        """
        ...

    def setAudioFormat(self, format: "QAudioFormat") -> None:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#setAudioFormat

        **void QAudioDecoder::setAudioFormat(const QAudioFormat & format )**

        Set the desired audio format for decoded samples to **format**.

        This property can only be set while the decoder is stopped. Setting this
        property at other times will be ignored.

        If the decoder does not support this format, **error** () will be set to
        `FormatError`.

        If you do not specify a format, the format of the decoded audio itself
        will be used. Otherwise, some format conversion will be applied.

        If you wish to reset the decoded format to that of the original audio
        file, you can specify an invalid **format**.

        **Warning:** Setting a desired audio format is not yet supported on
        Android.

        **See also** **audioFormat** ().
        """
        ...

    def audioFormat(self) -> "QAudioFormat":
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#audioFormat

        **QAudioFormat QAudioDecoder::audioFormat() const**

        Returns the audio format the decoder is set to.

        **Note:** This may be different than the format of the decoded samples,
        if the audio format was set to an invalid one.

        **See also** **setAudioFormat** () and **formatChanged** ().
        """
        ...

    def duration(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#duration

        **qint64 QAudioDecoder::duration() const**

        Returns total duration (in milliseconds) of the audio stream or -1 if
        not available.
        """
        ...

    def position(self) -> int:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#position

        **qint64 QAudioDecoder::position() const**

        Returns position (in milliseconds) of the last buffer read from the
        decoder or -1 if no buffers have been read.
        """
        ...

    def bufferAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#bufferAvailable

        **bool QAudioDecoder::bufferAvailable() const**

        Returns true if a buffer is available to be read, and false otherwise.
        If there is no buffer available, calling the **read** () function will
        return an invalid buffer.

        **Note:** Getter function for property bufferAvailable.
        """
        ...

    def read(self) -> QAudioBuffer:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#read

        **QAudioBuffer QAudioDecoder::read() const**

        Read a buffer from the decoder, if one is available. Returns an invalid
        buffer if there are no decoded buffers currently available, or on
        failure. In both cases this function will not block.

        You should either respond to the **bufferReady** () signal or check the
        **bufferAvailable** () function before calling read() to make sure you
        get useful data.
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#errorString

        **QString QAudioDecoder::errorString() const**

        Returns a human readable description of the current error, or an empty
        string is there is no error.

        **Note:** Getter function for property **error** .
        """
        ...

    def setSourceDevice(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#setSourceDevice

        **void QAudioDecoder::setSourceDevice(QIODevice * device )**

        Sets the current audio **QIODevice**  to **device**.

        When this property is set any current decoding is stopped, and any audio
        buffers are discarded.

        You can only specify either a source filename or a source **QIODevice**
        . Setting one will unset the other.

        **See also** **sourceDevice** ().
        """
        ...

    def sourceDevice(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#sourceDevice

        **QIODevice *QAudioDecoder::sourceDevice() const**

        Returns the current source **QIODevice** , if one was set. If
        **setSource** () was called, this will be a nullptr.

        **See also** **setSourceDevice** ().
        """
        ...

    def setSource(self, fileName: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#setSource

        **void QAudioDecoder::setSource(const QUrl & fileName )**

        Sets the current audio file name to **fileName**.

        When this property is set any current decoding is stopped, and any audio
        buffers are discarded.

        You can only specify either a source filename or a source **QIODevice**
        . Setting one will unset the other.

        **Note:** Setter function for property **source** .

        **See also** **source** ().
        """
        ...

    def source(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#source

        **QUrl QAudioDecoder::source() const**

        Returns the current file name to decode. If **setSourceDevice**  was
        called, this will be empty.

        **Note:** Getter function for property source.

        **See also** **setSource** ().
        """
        ...

    def isDecoding(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#isDecoding-prop

        **[read-only] isDecoding : const bool**

        `true` if the decoder is currently running and decoding audio data.

        **Access functions:**

        bool **isDecoding** () const

        **Notifier signal:**

        void **isDecodingChanged** (bool)
        """
        ...

    def isSupported(self) -> bool:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#isSupported

        **bool QAudioDecoder::isSupported() const**

        Returns true is audio decoding is supported on this platform.
        """
        ...

    @property
    def bufferAvailableChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#bufferAvailableChanged

        **[signal] void QAudioDecoder::bufferAvailableChanged(bool available )**

        Signals the availability (if **available** is true) of a new buffer.

        If **available** is false, there are no buffers available.

        **Note:** Notifier signal for property **bufferAvailable** .

        **See also** **bufferAvailable** () and **bufferReady** ().
        """
        ...

    @property
    def bufferReady(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#bufferReady

        **[signal] void QAudioDecoder::bufferReady()**

        Signals that a new decoded audio buffer is available to be read.

        **See also** **read** () and **bufferAvailable** ().
        """
        ...

    @property
    def durationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#durationChanged

        **[signal] void QAudioDecoder::durationChanged(qint64 duration )**

        Signals that the estimated **duration** of the decoded data has changed.

        **See also** **positionChanged** ().
        """
        ...

    @property
    def error(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#error-prop

        **[read-only] error : const QString**

        This property holds the current error state.

        **Access functions:**

        QString ****errorString** ** () const
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#finished

        **[signal] void QAudioDecoder::finished()**

        Signals that the decoding has finished successfully. If decoding fails,
        error signal is emitted instead.

        **See also** **start** (), **stop** (), and **error** ().
        """
        ...

    @property
    def formatChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#formatChanged

        **[signal] void QAudioDecoder::formatChanged(const QAudioFormat & format
        )**

        Signals that the current audio format of the decoder has changed to
        **format**.

        **See also** **audioFormat** () and **setAudioFormat** ().
        """
        ...

    @property
    def isDecodingChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def positionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#positionChanged

        **[signal] void QAudioDecoder::positionChanged(qint64 position )**

        Signals that the current **position** of the decoder has changed.

        **See also** **durationChanged** ().
        """
        ...

    @property
    def sourceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qaudiodecoder.html#sourceChanged

        **[signal] void QAudioDecoder::sourceChanged()**

        Signals that the current source of the decoder has changed.

        **Note:** Notifier signal for property **source** .

        **See also** **source** () and **sourceDevice** ().
        """
        ...
